@@ -7,7 +7,7 @@ from tqdm import tqdm
 from mrftools import DictionaryParameters, SequenceParameters
 
 class Simulation: 
-    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[], singularValues=[]):
+    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[], singularValues=[], intialMz=-0.95):
         self.sequenceParameters = sequenceParameters
         self.dictionaryParameters = dictionaryParameters
         if numTimepoints == -1:
@@ -19,13 +19,14 @@ class Simulation:
         self.truncationMatrix = truncationMatrix
         self.truncatedResults = truncatedResults
         self.singularValues = singularValues
+        self.initialMz = intialMz
         if not name:
             self.name = sequenceParameters.name + "_" + dictionaryParameters.name + "_" + str(numSpins) # Doesn't account for phase range
         else:
             self.name = name
 
     @staticmethod
-    def Simulate(numTimepoints,T1s,T2s,B1s,TRs,TEs,FAs,spinOffresonances,device=None):     
+    def Simulate(numTimepoints,T1s,T2s,B1s,TRs,TEs,FAs,spinOffresonances,device=None, initialMz=-0.95):     
         if(device==None):
             if torch.cuda.is_available():
                 device = torch.device("cuda")
@@ -48,7 +49,7 @@ class Simulation:
         phaseValueCosines = torch.cos(spinOffresonances)
         phaseValueSines = torch.sin(spinOffresonances)
         
-        Mz[:] = -0.95
+        Mz[:] = initialMz
         with torch.no_grad():
             for iTimepoint in range(numTimepoints):
                 fa = FAs[iTimepoint] * B1s
@@ -120,7 +121,7 @@ class Simulation:
                 T1s = np.copy(self.dictionaryParameters.entries[firstDictEntry:lastDictEntry]['T1'])
                 T2s = np.copy(self.dictionaryParameters.entries[firstDictEntry:lastDictEntry]['T2'])
                 B1s = np.copy(self.dictionaryParameters.entries[firstDictEntry:lastDictEntry]['B1'])
-                Mx0,My0,Mz0 = self.Simulate(self.numTimepoints, T1s, T2s, B1s, TRs, TEs, FAs, phaseValues, device=device)
+                Mx0,My0,Mz0 = self.Simulate(self.numTimepoints, T1s, T2s, B1s, TRs, TEs, FAs, phaseValues, device=device, initialMz=self.initialMz)
                 Mx = torch.mean(Mx0, axis=1)    
                 My = torch.mean(My0, axis=1)    
                 Mxy[:,firstDictEntry:lastDictEntry] = Mx+(My*1j)
